@@ -48,8 +48,8 @@ static std::vector<ustring> format_list_vector;
 // Which format names and extensions are procedural (not reading from files)
 static std::set<std::string> procedural_plugins;
 
-static std::string pattern = Strutil::sprintf(".imageio.%s",
-                                              Plugin::plugin_extension());
+static std::string pattern = Strutil::fmt::format(".imageio.{}",
+                                                  Plugin::plugin_extension());
 
 
 inline void
@@ -135,7 +135,7 @@ declare_imageio_format_locked(const std::string& format_name,
         format_library_versions[format_name] = lib_version;
         if (library_list.length())
             library_list += std::string(";");
-        library_list += Strutil::sprintf("%s:%s", format_name, lib_version);
+        library_list += Strutil::fmt::format("{}:{}", format_name, lib_version);
         // std::cout << format_name << ": " << lib_version << "\n";
     }
 }
@@ -280,6 +280,7 @@ PLUGENTRY(ico);
 PLUGENTRY(iff);
 PLUGENTRY(jpeg);
 PLUGENTRY(jpeg2000);
+PLUGENTRY(jpegxl);
 PLUGENTRY(null);
 PLUGENTRY(openexr);
 PLUGENTRY(openvdb);
@@ -287,6 +288,7 @@ PLUGENTRY(png);
 PLUGENTRY(pnm);
 PLUGENTRY_RO(psd);
 PLUGENTRY_RO(ptex);
+PLUGENTRY_RO(r3d);
 PLUGENTRY_RO(raw);
 PLUGENTRY(rla);
 PLUGENTRY(sgi);
@@ -382,6 +384,9 @@ catalog_builtin_plugins()
 #if defined(USE_OPENJPEG) && !defined(DISABLE_JPEG2000)
     DECLAREPLUG (jpeg2000);
 #endif
+#if defined(USE_JXL)
+    DECLAREPLUG (jpegxl);
+#endif
 #if !defined(DISABLE_NULL)
     DECLAREPLUG (null);
 #endif
@@ -400,6 +405,9 @@ catalog_builtin_plugins()
 #if defined(USE_PTEX) && !defined(DISABLE_PTEX)
     DECLAREPLUG_RO (ptex);
 #endif
+#if defined(USE_R3DSDK) && !defined(DISABLE_R3D)
+    DECLAREPLUG_RO (r3d);
+#endif
 #if defined(USE_LIBRAW) && !defined(DISABLE_RAW)
     DECLAREPLUG_RO (raw);
 #endif
@@ -460,6 +468,8 @@ pvt::catalog_all_plugins(std::string searchpath)
     std::call_once(builtin_flag, catalog_builtin_plugins);
 
     std::unique_lock<std::recursive_mutex> lock(imageio_mutex);
+    append_if_env_exists(searchpath, "OPENIMAGEIO_PLUGIN_PATH", true);
+    // obsolete name:
     append_if_env_exists(searchpath, "OIIO_LIBRARY_PATH", true);
 
     size_t patlen = pattern.length();
@@ -516,7 +526,7 @@ ImageOutput::create(string_view filename, Filesystem::IOProxy* ioproxy,
 {
     std::unique_ptr<ImageOutput> out;
     if (filename.empty()) {  // Can't even guess if no filename given
-        OIIO::pvt::errorfmt("ImageOutput::create() called with no filename");
+        OIIO::errorfmt("ImageOutput::create() called with no filename");
         return out;
     }
 
@@ -553,9 +563,9 @@ ImageOutput::create(string_view filename, Filesystem::IOProxy* ioproxy,
                 const char* msg
                     = "ImageOutput::create() could not find any ImageOutput plugins!  Perhaps you need to set OIIO_LIBRARY_PATH.\n";
                 Strutil::print(stderr, "{}", msg);
-                OIIO::pvt::errorfmt("{}", msg);
+                OIIO::errorfmt("{}", msg);
             } else
-                OIIO::pvt::errorfmt(
+                OIIO::errorfmt(
                     "OpenImageIO could not find a format writer for \"{}\". "
                     "Is it a file format that OpenImageIO doesn't know about?\n",
                     filename);
@@ -572,7 +582,7 @@ ImageOutput::create(string_view filename, Filesystem::IOProxy* ioproxy,
     }
     if (out && ioproxy) {
         if (!out->supports("ioproxy")) {
-            OIIO::pvt::errorfmt(
+            OIIO::errorfmt(
                 "ImageOutput::create called with IOProxy, but format {} does not support IOProxy",
                 out->format_name());
             out.reset();
@@ -585,54 +595,6 @@ ImageOutput::create(string_view filename, Filesystem::IOProxy* ioproxy,
 
 
 
-// DEPRECATED(2.2)
-std::unique_ptr<ImageOutput>
-ImageOutput::create(const std::string& filename,
-                    const std::string& plugin_searchpath)
-{
-    return create(filename, nullptr, plugin_searchpath);
-}
-
-
-
-void
-ImageOutput::destroy(ImageOutput* x)
-{
-    delete x;
-}
-
-
-
-// DEPRECATED(2.1)
-std::unique_ptr<ImageInput>
-ImageInput::create(const std::string& filename,
-                   const std::string& plugin_searchpath)
-{
-    return create(filename, false, nullptr, plugin_searchpath);
-}
-
-
-
-// DEPRECATED(2.1)
-std::unique_ptr<ImageInput>
-ImageInput::create(const std::string& filename, bool do_open,
-                   const std::string& plugin_searchpath)
-{
-    return create(filename, do_open, nullptr, plugin_searchpath);
-}
-
-
-
-// DEPRECATED(2.2)
-std::unique_ptr<ImageInput>
-ImageInput::create(const std::string& filename, bool do_open,
-                   const ImageSpec* config, string_view plugin_searchpath)
-{
-    return create(filename, do_open, config, nullptr, plugin_searchpath);
-}
-
-
-
 std::unique_ptr<ImageInput>
 ImageInput::create(string_view filename, bool do_open, const ImageSpec* config,
                    Filesystem::IOProxy* ioproxy, string_view plugin_searchpath)
@@ -647,7 +609,7 @@ ImageInput::create(string_view filename, bool do_open, const ImageSpec* config,
     // Only check REST arguments if the file does not exist
     if (!Filesystem::exists(filename)) {
         if (!Strutil::get_rest_arguments(filename, filename_stripped, args)) {
-            OIIO::pvt::errorfmt(
+            OIIO::errorfmt(
                 "ImageInput::create() called with malformed filename");
             return in;
         }
@@ -657,7 +619,7 @@ ImageInput::create(string_view filename, bool do_open, const ImageSpec* config,
         filename_stripped = filename;
 
     if (filename_stripped.empty()) {  // Can't even guess if no filename given
-        OIIO::pvt::errorfmt("ImageInput::create() called with no filename");
+        OIIO::errorfmt("ImageInput::create() called with no filename");
         return in;
     }
 
@@ -808,18 +770,18 @@ ImageInput::create(string_view filename, bool do_open, const ImageSpec* config,
                 = "ImageInput::create() could not find any ImageInput plugins!\n"
                   "    Perhaps you need to set OIIO_LIBRARY_PATH.\n";
             Strutil::print(stderr, "{}", msg);
-            OIIO::pvt::errorfmt("{}", msg);
+            OIIO::errorfmt("{}", msg);
         } else if (!specific_error.empty()) {
             // Pass along any specific error message we got from our
             // best guess of the format.
-            OIIO::pvt::errorfmt("{}", specific_error);
+            OIIO::errorfmt("{}", specific_error);
         } else if (Filesystem::exists(filename))
-            pvt::errorfmt(
+            OIIO::errorfmt(
                 "OpenImageIO could not find a format reader for \"{}\". "
                 "Is it a file format that OpenImageIO doesn't know about?\n",
                 filename);
         else
-            OIIO::pvt::errorfmt(
+            OIIO::errorfmt(
                 "Image \"{}\" does not exist. Also, it is not the name of an image format that OpenImageIO recognizes.\n",
                 filename);
         OIIO_DASSERT(!in);
@@ -830,12 +792,4 @@ ImageInput::create(string_view filename, bool do_open, const ImageSpec* config,
 }
 
 
-
-void
-ImageInput::destroy(ImageInput* x)
-{
-    delete x;
-}
-
-
 OIIO_NAMESPACE_END
