@@ -34,7 +34,7 @@ static std::string output_filename;
 static std::string output_format;
 static std::vector<char> buffer;
 static ImageSpec bufspec, outspec;
-static ImageCache* imagecache         = NULL;
+static std::shared_ptr<ImageCache> imagecache;
 static imagesize_t total_image_pixels = 0;
 static float cache_size               = 0;
 
@@ -54,13 +54,13 @@ getargs(int argc, char* argv[])
     ap.arg("-v", &verbose)
       .help("Verbose mode");
     ap.arg("--threads %d", &numthreads)
-      .help(Strutil::sprintf("Number of threads (default: %d)", numthreads));
+      .help(Strutil::fmt::format("Number of threads (default: {})", numthreads));
     ap.arg("--iters %d", &iterations)
-      .help(Strutil::sprintf("Number of iterations (default: %d)", iterations));
+      .help(Strutil::fmt::format("Number of iterations (default: {})", iterations));
     ap.arg("--trials %d", &ntrials)
       .help("Number of trials");
     ap.arg("--autotile %d", &autotile_size)
-      .help(Strutil::sprintf("Autotile size (when used; default: %d)", autotile_size));
+      .help(Strutil::fmt::format("Autotile size (when used; default: {})", autotile_size));
     ap.arg("--iteronly", &iter_only)
       .help("Run ImageBuf iteration tests only (not read tests)");
     ap.arg("--noiter", &no_iter)
@@ -142,7 +142,7 @@ time_read_imagebuf()
 {
     imagecache->invalidate_all(true);
     for (ustring filename : input_filename) {
-        ImageBuf ib(filename.string(), imagecache);
+        ImageBuf ib(filename, 0, 0, imagecache);
         ib.read(0, 0, true, conversion);
     }
 }
@@ -172,10 +172,8 @@ test_read(const std::string& explanation, void (*func)(), int autotile = 64,
     imagecache->attribute("autoscanline", autoscanline);
     double t    = time_trial(func, ntrials);
     double rate = double(total_image_pixels) / t;
-    std::cout << "  " << explanation << ": "
-              << Strutil::timeintervalformat(t, 2) << " = "
-              << Strutil::sprintf("%5.1f", rate / 1.0e6) << " Mpel/s"
-              << std::endl;
+    print("  {}: {} = {:5.1f} Mpel/s\n", explanation,
+          Strutil::timeintervalformat(t, 2), rate / 1.0e6);
 }
 
 
@@ -282,7 +280,7 @@ time_write_tiles_row_at_a_time()
 static void
 time_write_imagebuf()
 {
-    ImageBuf ib(output_filename, bufspec, &buffer[0]);  // wrap the buffer
+    ImageBuf ib(bufspec, span(buffer));  // wrap the buffer
     auto out = ImageOutput::create(output_filename);
     OIIO_ASSERT(out);
     bool ok = out->open(output_filename, outspec);
@@ -299,10 +297,8 @@ test_write(const std::string& explanation, void (*func)(), int tilesize = 0)
     outspec.tile_depth  = 1;
     double t            = time_trial(func, ntrials);
     double rate         = double(total_image_pixels) / t;
-    std::cout << "  " << explanation << ": "
-              << Strutil::timeintervalformat(t, 2) << " = "
-              << Strutil::sprintf("%5.1f", rate / 1.0e6) << " Mpel/s"
-              << std::endl;
+    print("  {}: {} = {:5.1f} Mpel/s\n", explanation,
+          Strutil::timeintervalformat(t, 2), rate / 1.0e6);
 }
 
 
@@ -444,14 +440,12 @@ test_pixel_iteration(const std::string& explanation,
     // Force the whole image to be read at once
     imagecache->attribute("autotile", autotile);
     imagecache->attribute("autoscanline", 1);
-    ImageBuf ib(input_filename[0].string(), imagecache);
+    ImageBuf ib(input_filename[0], 0, 0, imagecache);
     ib.read(0, 0, preload, TypeFloat);
     double t    = time_trial(std::bind(func, std::ref(ib), iters), ntrials);
     double rate = double(ib.spec().image_pixels()) / (t / iters);
-    std::cout << "  " << explanation << ": "
-              << Strutil::timeintervalformat(t / iters, 3) << " = "
-              << Strutil::sprintf("%5.1f", rate / 1.0e6) << " Mpel/s"
-              << std::endl;
+    print("  {}: {} = {:5.1f} Mpel/s\n", explanation,
+          Strutil::timeintervalformat(t / iters, 3), rate / 1.0e6);
 }
 
 
@@ -502,7 +496,7 @@ main(int argc, char** argv)
     imagesize_t maxpelchans = 0;
     for (auto&& fn : input_filename) {
         ImageSpec spec;
-        if (!imagecache->get_imagespec(fn, spec, 0, 0, true)) {
+        if (!imagecache->get_imagespec(fn, spec)) {
             std::cout << "File \"" << fn << "\" could not be opened.\n";
             return -1;
         }
@@ -617,6 +611,5 @@ main(int argc, char** argv)
     if (verbose)
         std::cout << "\n" << imagecache->getstats(2) << "\n";
 
-    ImageCache::destroy(imagecache);
     return unit_test_failures;
 }
